function tuning=design_tuning
%
% call:  tuning=design_tuning
%
% tuning = structure containing the tuning parameters of the
% cutting planes optimization solver optim_new.m, and also (see below):
% * tuning.amp
% * tuning.tol_constraint
% * tuning.tol_constraint_lft
% * tuning.zero_T4
%
tuning=[];
%
% verbatim = 0/1: display of intermediate results.
%
tuning.verbatim=0;
%
% Let Jinf be the lower bound of the minimization objective.
% Let Jsup be the upper bound.
% The algorithm stops if Jsup-Jinf <= tol * Jsup
%
tuning.tol=0.05;
%
% eps_cvge_cutting_plane > 0 may improve the convergence, but it's
% dangerous ! Please choose eps_cvge_cutting_plane between 0 and 0.01
%
tuning.eps_cvge_cutting_plane=0.01;
%
% The infinity norm of theta, the vector of optimization parameters, is limited to
% theta_max. theta_max = Inf is possible. A very large, but not infinite value is advised,
% e.g. theta_max = 1e10.
%
tuning.theta_max=1e10; % a positive value please
%
% beta is used to remove old LP constraints. Please choose beta between 0 and 1.
% If beta = 0 no LP constraint will be removed. A typical value is beta = 0.
% (useless if is_sigma=0 or 2 below)
%
tuning.beta=0;
%
% Maximal allowable tolerance on the LP constraints.
% If this tolerance is violated a warning message is produced.
%
tuning.tol_LP_constraints=1e-3;
%
% is_sigma = 0/1/2: classical (0) or central (1) cutting planes method,
% or a mixed method (2) combining the central and classical ones.
%
tuning.is_sigma=0;
%
% Computation of an improved lower bound of the minimization objective
% each N_lower_bound iterations (useless if is_sigma=0 or 2).
%
tuning.N_lower_bound=5;
%
% Computation of an improved upper bound of the minimization objective
% each N_upper_bound iterations (useless if is_sigma=1).
%
tuning.N_upper_bound=5;
%
% Maximal number of iterations
%
tuning.nbr_iter_max=500;
%
% The algorithm stops if the decrease of the criterion is less than
% tuning.threshold during tuning.N_threshold iterations
%
tuning.threshold=1e-2;
tuning.N_threshold=30;
%
% Value of the min. objective, under which the optimization solver stops
%
tuning.obj_min=1e-3;
%
% Amplitude of the optimization parameters for the linearity test
% of T1 + T2 Q T3 w.r.t. Q
%
tuning.amp=1;
%
% Tolerance on the constraints for the multi-model computation
% of the feedback controller
%
tuning.tol_constraint=0.01;
%
% Tolerance on the constraints for the validation of the feedback
% controller on the LFT model
%
% tuning.tol_constraint_lft > tuning.tol_constraint is required
%
tuning.tol_constraint_lft=0.05;
%
% zero_T4 = 1 --> The structure [T1 T2; T3 0] is imposed
% during the multi-model validation step
%
tuning.zero_T4=0;
%
% Please don't change the variables below.
%
tuning.nbr_variables=0;
tuning.lp_method=1;
tuning.one_shot_freq_design=0;

